==> haskell-chell-quickcheck-0.2.5.4-107-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-FJuXSZkMR0cJyaARq39zuF
key:                  chell-quickcheck-0.2.5.4-FJuXSZkMR0cJyaARq39zuF
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  689f4a56aced0757c06a6d3e28e61be4
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-FJuXSZkMR0cJyaARq39zuF
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS base-4.18.2.1
    chell-0.5.0.2-7mRYbmmQgnJ3glUfHFLIH2
    random-1.2.1.3-LIVoFEqTBeMDojO1AYDBLj

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.4-108-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 chell-quickcheck
version:              0.2.5.4
visibility:           public
id:                   chell-quickcheck-0.2.5.4-1W34hcOI7vbDDdNIHtQqlo
key:                  chell-quickcheck-0.2.5.4-1W34hcOI7vbDDdNIHtQqlo
license:              MIT
maintainer:           Chris Martin, Julie Moronuki
author:               John Millikin <john@john-millikin.com>
homepage:             https://github.com/typeclasses/chell
synopsis:             QuickCheck support for Chell
description:          QuickCheck support for the Chell testing library.
category:             Testing
abi:                  adf796ed08ff0b5df239f6c7a554e848
exposed:              True
exposed-modules:      Test.Chell.QuickCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/chell-quickcheck-0.2.5.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-chell-quickcheck
hs-libraries:         HSchell-quickcheck-0.2.5.4-1W34hcOI7vbDDdNIHtQqlo
depends:
    QuickCheck-2.15.0.1-7BzLIlrrsyUAWv4ugiuXtJ base-4.18.2.1
    chell-0.5.0.2-BuH0O4tm2M8LiCbiAwOxFR
    random-1.2.1.3-6l1YOhgkyj83HD6td8a68Q

haddock-interfaces:
    /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock

haddock-html:         /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
